@@ -1,6 +1,6 @@
 package Weed::Generator;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009';
 
 use Weed 'X3DGenerator';
 
@@ -37,9 +37,6 @@ use constant NULL  => $_NULL_;
 
 use constant DEF => $_DEF_;
 
-use constant ROUTE => $_ROUTE_;
-use constant TO    => $_TO_;
-
 use constant tab   => $_tab_;
 use constant space => $_space_;
 use constant break => $_break_;
@@ -190,8 +187,10 @@ sub setOutputStyle {
 
 # STANDARD
 __PACKAGE__->setPrecisionOfFloat(7);
-__PACKAGE__->setPrecisionOfDouble(14);
+__PACKAGE__->setPrecisionOfDouble(15);
+__PACKAGE__->setOutputStyle("CLEAN");
 __PACKAGE__->setOutputStyle("TIDY");
 
 1;
 __END__
+#__PACKAGE__->CLEAN;
